import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.assets._jsii
import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_codecommit._jsii
import aws_cdk.aws_codestarnotifications._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_ecr._jsii
import aws_cdk.aws_ecr_assets._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kms._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_assets._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.core._jsii
import aws_cdk.region_info._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-codebuild",
    "1.122.0",
    __name__[0:-6],
    "aws-codebuild@1.122.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
